==> kubernetes-annotations-2.6.0-sources.jar: io/dekorate/kubernetes/config/RollingUpdateBuilder.java <==
package io.dekorate.kubernetes.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class RollingUpdateBuilder extends io.dekorate.kubernetes.config.RollingUpdateFluentImpl<io.dekorate.kubernetes.config.RollingUpdateBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.dekorate.kubernetes.config.RollingUpdate,io.dekorate.kubernetes.config.RollingUpdateBuilder>{
  public RollingUpdateBuilder() {
    this(false);
  }
  public RollingUpdateBuilder(java.lang.Boolean validationEnabled) {
    this(new RollingUpdate(), validationEnabled);
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdateFluent<?> fluent) {
    this(fluent, false);
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RollingUpdate(), validationEnabled);
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdateFluent<?> fluent,io.dekorate.kubernetes.config.RollingUpdate instance) {
    this(fluent, instance, false);
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdateFluent<?> fluent,io.dekorate.kubernetes.config.RollingUpdate instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMaxUnavailable(instance.getMaxUnavailable()); 
    fluent.withMaxSurge(instance.getMaxSurge()); 
    this.validationEnabled = validationEnabled; 
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdate instance) {
    this(instance,false);
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdate instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withMaxSurge(instance.getMaxSurge()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.kubernetes.config.RollingUpdateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.dekorate.kubernetes.config.EditableRollingUpdate build() {
    EditableRollingUpdate buildable = new EditableRollingUpdate(fluent.getMaxUnavailable(),fluent.getMaxSurge());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RollingUpdateBuilder that = (RollingUpdateBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-annotations-2.11.3-sources.jar: io/dekorate/kubernetes/config/RollingUpdateBuilder.java <==
package io.dekorate.kubernetes.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class RollingUpdateBuilder extends RollingUpdateFluentImpl<RollingUpdateBuilder> implements VisitableBuilder<io.dekorate.kubernetes.config.RollingUpdate,io.dekorate.kubernetes.config.RollingUpdateBuilder>{
  public RollingUpdateBuilder() {
    this(false);
  }
  public RollingUpdateBuilder(Boolean validationEnabled) {
    this(new RollingUpdate(), validationEnabled);
  }
  public RollingUpdateBuilder(RollingUpdateFluent<?> fluent) {
    this(fluent, false);
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RollingUpdate(), validationEnabled);
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdateFluent<?> fluent,io.dekorate.kubernetes.config.RollingUpdate instance) {
    this(fluent, instance, false);
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdateFluent<?> fluent,io.dekorate.kubernetes.config.RollingUpdate instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMaxUnavailable(instance.getMaxUnavailable()); 
    fluent.withMaxSurge(instance.getMaxSurge()); 
    this.validationEnabled = validationEnabled; 
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdate instance) {
    this(instance,false);
  }
  public RollingUpdateBuilder(io.dekorate.kubernetes.config.RollingUpdate instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withMaxSurge(instance.getMaxSurge()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.kubernetes.config.RollingUpdateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public EditableRollingUpdate build() {
    EditableRollingUpdate buildable = new EditableRollingUpdate(fluent.getMaxUnavailable(),fluent.getMaxSurge());
    return buildable;
  }
  
}
